@@ -11,9 +11,6 @@
 /* Everything using inb/outb, etc needs "compiler.h" */
 #include "compiler.h"
 
-/* This is used for module versioning */
-#include "xf86Version.h"
-
 /* Drivers for PCI hardware need this */
 #include "xf86PciInfo.h"
 
@@ -242,8 +239,10 @@ extern void     ApmAdjustFrame(int scrnIndex, int x, int y, int flags);
 extern void	ApmHWCursorReserveSpace(ApmPtr pApm);
 extern void	ApmAccelReserveSpace(ApmPtr pApm);
 
+#ifdef XF86RUSH
 extern int	ApmPixmapIndex;
 #define APM_GET_PIXMAP_PRIVATE(pix)\
 	((ApmPixmapPtr)(((PixmapPtr)(pix))->devPrivates[ApmPixmapIndex].ptr))
+#endif
 
 #include "apm_regs.h"
